pub enum SecurityVerifierVerdictStatus {
Survivor,
Dismissed,
NeedsHumanReview,
}Expand description
Verifier verdict status accepted by fallow security survivors.
Variants
Survivor
The verifier could not dismiss the candidate from supplied evidence.
Dismissed
The verifier dismissed the candidate from supplied evidence.
NeedsHumanReview
The verifier needs human review before dismissal or remediation.