pub struct ToolVersion(pub String);Expand description
Fallow CLI version that produced this envelope. Renders to the JSON wire as
a bare string (e.g. "2.74.0").
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ToolVersion
impl Clone for ToolVersion
Sourcefn clone(&self) -> ToolVersion
fn clone(&self) -> ToolVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolVersion
impl Debug for ToolVersion
impl Eq for ToolVersion
Sourceimpl JsonSchema for ToolVersion
impl JsonSchema for ToolVersion
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolVersion
impl PartialEq for ToolVersion
Sourceimpl Serialize for ToolVersion
impl Serialize for ToolVersion
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ToolVersion