markdown_table_code_span

Function markdown_table_code_span 

pub fn markdown_table_code_span(value: &str) -> String
markdown_code_span for a Markdown table cell: pipes are additionally escaped so the value cannot terminate the cell, and line endings collapse to spaces because any CommonMark line ending would split the table row.