pub struct EntryWeightDelta {
pub path: String,
pub baseline_eager_bytes: Option<u64>,
pub current_eager_bytes: Option<u64>,
pub baseline_eager_modules: Option<usize>,
pub current_eager_modules: Option<usize>,
pub new_eager_packages: Vec<String>,
pub exceeded: bool,
}Expand description
Change of one entry against the regression baseline.
Fields
path: StringEntry file, relative to the analysed root.
baseline_eager_bytes: Option<u64>Baseline eager_bytes; absent for an entry that is new in this run.
current_eager_bytes: Option<u64>Current eager_bytes; absent for an entry that is gone in this run.
baseline_eager_modules: Option<usize>Baseline eager_modules; absent for an entry that is new in this run.
current_eager_modules: Option<usize>Current eager_modules; absent for an entry that is gone in this run.
new_eager_packages: Vec<String>Packages on the eager path now that the baseline did not have.
exceeded: boolWhether the growth of eager_bytes is larger than the tolerance.