pub struct HealthConfiguredThresholds {
pub max_cyclomatic: Option<u16>,
pub max_cognitive: Option<u16>,
pub max_crap: Option<f64>,
pub max_unit_size: Option<u32>,
}Expand description
Threshold values configured by a single override entry.
Fields
max_cyclomatic: Option<u16>Cyclomatic ceiling set by the override, when it sets one.
max_cognitive: Option<u16>Cognitive ceiling set by the override, when it sets one.
max_crap: Option<f64>CRAP ceiling set by the override, when it sets one.
max_unit_size: Option<u32>Unit-size ceiling set by the override, when it sets one.