pub struct ImpactDigestCounts {
pub containment_count: usize,
pub resolved_total: usize,
}Expand description
Local impact digest counters used to render the impact-report next step.
Fields
containment_count: usizeCommits contained at the gate according to the local impact digest.
resolved_total: usizeFindings resolved according to the local impact digest.