pub struct ReviewBriefSubtractSections {
pub dead_code: Option<Value>,
pub duplication: Option<Value>,
pub complexity: Option<Value>,
}Expand description
CLI-built audit subreports that are embedded in the audit brief envelope.
The brief envelope and field ordering belong to fallow-output; the
underlying subreport payloads are still supplied by the CLI until their
builders are fully command-neutral.
Fields
dead_code: Option<Value>duplication: Option<Value>complexity: Option<Value>Trait Implementations
Sourceimpl Clone for ReviewBriefSubtractSections
impl Clone for ReviewBriefSubtractSections
Sourcefn clone(&self) -> ReviewBriefSubtractSections
fn clone(&self) -> ReviewBriefSubtractSections
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReviewBriefSubtractSections
impl Debug for ReviewBriefSubtractSections
Sourceimpl Default for ReviewBriefSubtractSections
impl Default for ReviewBriefSubtractSections
Sourcefn default() -> ReviewBriefSubtractSections
fn default() -> ReviewBriefSubtractSections
Returns the “default value” for a type. Read more