WorkspacesOutput

Struct WorkspacesOutput 

pub struct WorkspacesOutput<Diagnostic> {
    pub workspace_count: usize,
    pub workspaces: Vec<WorkspaceInfo>,
    pub workspace_diagnostics: Vec<Diagnostic>,
}
fallow workspaces --format json envelope.

Fields

workspace_count: usize

Number of workspace package entries in workspaces.

workspaces: Vec<WorkspaceInfo>

Workspace packages discovered from package manager and tsconfig workspace declarations. Paths are project-root-relative and use forward slashes.

workspace_diagnostics: Vec<Diagnostic>

Workspace discovery diagnostics produced while reading workspace declarations. Paths are project-root-relative and use forward slashes, like workspaces[].path and like the workspace_diagnostics[] array on the analysis envelopes. Present for compatibility with the current wire contract, even when empty.