pub fn serialize_json_root_output<T: Serialize>(
output: T,
mode: RootEnvelopeMode,
) -> Result<Value, Error>Expand description
Serialize a typed fallow root envelope with the requested discriminator mode.
Errors
Returns a serde error when the provided envelope cannot be converted to a JSON value.